@@ -7,7 +7,7 @@ use Carp;
 use Image::LibRSVG;
 use MIME::Types;
 
-our $VERSION = 0.02;
+our $VERSION = 0.0211;
 
 has 'format' => ( is => 'ro', isa => 'Str', default => 'svg' );
 
@@ -67,9 +67,9 @@ If you want, say a comparative line graph of mutiple sets of data:
 sub process {
     my ( $self, $c ) = @_;
 
-    my ( $type, $title, $fields, $data ) = map {
+    my ( $type, $fields, $data ) = map {
         $c->stash->{"chart_" . $_} or croak("\$c->stash->{chart_$_} not set")
-    } qw(type title fields data);
+    } qw(type fields data);
 
     $type =~ m/^(Bar(Horizontal)?|Pie|Line)$/ or croak("Invalid chart type $type");
 
@@ -79,7 +79,11 @@ sub process {
     };
 
     $conf->{fields} = $fields;
-    $conf->{graph_title} = $title if $title;
+    
+    if (my $title = $c->stash->{chart_title} || $conf->{graph_title}) {
+        $conf->{graph_title} = $title;
+        $conf->{show_graph_title} = 1;
+    }
 
     my $class = "SVG::TT::Graph::$type";
 
@@ -118,9 +122,9 @@ sub process {
     }
 }
 
-=head1 OPTIONS
+=head1 CONFIG OPTIONS
 
-Options can be set in the config or in the stash
+B<Note:> These can be overridden by stashing parameters with the same name
 
 =head2 format
 
@@ -128,7 +132,73 @@ Can be svg, png, gif, jpeg or any other format supported by L<Image::LibRSVG>
 
 =head2 chart_conf
 
-All options taken by L<SVG::TT::Graph> can be provided
+A hashref that takes all options to L<SVG::TT::Graph>::type . For the correct
+options, see the corresponding documentation:
+
+L<Bar Options|SVG::TT::Graph::Bar/new()>,
+
+L<Pie Options|SVG::TT::Graph::Pie/new()>,
+
+L<Line Options|SVG::TT::Graph::Line/new()>,
+
+L<BarLine Options|SVG::TT::Graph::BarLine/new()>,
+
+L<TimeSeries Options|SVG::TT::Graph::TimeSeries/new()>,
+
+L<BarHorizontal Options|SVG::TT::Graph::BarHorizontal/new()>
+
+=head1 STASHED PARAMETERS
+
+=head2 format
+
+An optional output format (svg/png/gif/jpeg..). Overrides config format
+
+=head2 chart_title
+
+An optional title for your chart
+
+=head2 chart_type
+
+Bar / Pie / Line / BarHorizontal / BarLine / TimeSeries
+
+=head2 chart_conf
+
+Any options taken by L<SVG::TT::Graph>
+
+=head2 chart_fields
+
+A list (array reference) of fields to show in your graph:
+
+    $c->stash->{fields} = [ 'Jan', 'Feb', 'March' .. ];
+
+=head2 chart_data
+
+If all you want is a singe data set, can be a hash reference of the form:
+
+    $c->stash->{chart_data} = { title => 'sales', values => [ 1.4, 2.2, ... ] }
+
+or a simple ArrayRef if you don't want a title
+
+    $c->stash->{chart_data} = [ 1.4, 2.2, ... ]
+
+If you want multiple data sets, use an array reference with each set in a hashref:
+
+    $c->stash->{chart_data} = [
+        { title => 'Barcelona', data => [ .. ] },
+        { title => 'Atletico', data => [ .. ] }
+    ];
+
+=head1 SAMPLE CHARTS
+
+See L<http://leo.cuckoo.org/projects/SVG-TT-Graph/>
+
+=head1 KNOWN BUGS
+
+For jpeg pie charts, background color transparency doesn't work
+
+=head1 REPOSITORY
+
+See L<git://github.com/terencemo/Catalyst--View--SVG--TT--Graph.git>
 
 =head1 SEE ALSO
 
